==> everycomp-1.20-2.8.7-fabric-sources.jar: net/mehvahdjukaar/every_compat/modules/fabric/red_bits/RedBitsModule.java <==
package net.mehvahdjukaar.every_compat.modules.fabric.red_bits;

import net.darktree.redbits.RedBits;
import net.darktree.redbits.blocks.LargeButtonBlock;
import net.mehvahdjukaar.every_compat.api.SimpleEntrySet;
import net.mehvahdjukaar.every_compat.api.SimpleModule;
import net.mehvahdjukaar.moonlight.api.set.wood.WoodType;
import net.mehvahdjukaar.moonlight.api.set.wood.WoodTypeRegistry;
import net.minecraft.class_2248;
import net.minecraft.class_3481;
import net.minecraft.class_3619;
import net.minecraft.class_4970;
import net.minecraft.class_7924;
import net.minecraft.class_8177;

//SUPPORT v1.16.1+
public class RedBitsModule extends SimpleModule {

    public final SimpleEntrySet<WoodType, class_2248> large_buttons;

    public RedBitsModule(String modId) {
        super(modId, "rb");

        large_buttons = SimpleEntrySet.builder(WoodType.class, "large_button",
                        () -> RedBits.OAK_LARGE_BUTTON, () -> WoodTypeRegistry.OAK_TYPE,
                        wood -> new LargeButtonBlock(true, new class_8177(wood.getTypeName()), class_4970.class_2251.method_9637()
                                .method_9634().method_9632(0.5F).method_50012(class_3619.field_15971))
                )
                .requiresChildren("button") // Recipes
                .addTag(class_3481.field_33713, class_7924.field_41254)
                .addTag(modRes("large_buttons"), class_7924.field_41254)
                .addTag(modRes("large_wooden_buttons"), class_7924.field_41254)
                .defaultRecipe()
                .build();
        this.addEntry(large_buttons);


    }
}

==> everycomp-1.20-2.9.5-fabric-sources.jar: net/mehvahdjukaar/every_compat/modules/fabric/red_bits/RedBitsModule.java <==
package net.mehvahdjukaar.every_compat.modules.fabric.red_bits;

import net.darktree.redbits.RedBits;
import net.darktree.redbits.blocks.LargeButtonBlock;
import net.mehvahdjukaar.every_compat.api.SimpleEntrySet;
import net.mehvahdjukaar.every_compat.api.SimpleModule;
import net.mehvahdjukaar.moonlight.api.set.wood.VanillaWoodTypes;
import net.mehvahdjukaar.moonlight.api.set.wood.WoodType;
import net.mehvahdjukaar.moonlight.api.set.wood.WoodTypeRegistry;
import net.minecraft.class_2248;
import net.minecraft.class_3481;
import net.minecraft.class_3619;
import net.minecraft.class_4970;
import net.minecraft.class_7924;
import net.minecraft.class_8177;

//SUPPORT v1.16.1+
public class RedBitsModule extends SimpleModule {

    public final SimpleEntrySet<WoodType, class_2248> large_buttons;

    public RedBitsModule(String modId) {
        super(modId, "rb");

        large_buttons = SimpleEntrySet.builder(WoodType.class, "large_button",
                        () -> RedBits.OAK_LARGE_BUTTON, () -> VanillaWoodTypes.OAK,
                        wood -> new LargeButtonBlock(true, new class_8177(wood.getTypeName()), class_4970.class_2251.method_9637()
                                .method_9634().method_9632(0.5F).method_50012(class_3619.field_15971))
                )
                .requiresChildren("button") // Recipes
                .addTag(class_3481.field_33713, class_7924.field_41254)
                .addTag(modRes("large_buttons"), class_7924.field_41254)
                .addTag(modRes("large_wooden_buttons"), class_7924.field_41254)
                .defaultRecipe()
                .build();
        this.addEntry(large_buttons);


    }
}
